@@ -956,15 +956,107 @@ class fundinfo(basicinfo):
         )
 
     def get_stock_holdings(self, year="", season="", month=""):
+        """
+        持仓个股细节
+
+        :param year:
+        :param season:
+        :param month:
+        :return: pd.DataFrame
+        """
         return get_fund_holdings(
             self.code, year, season=season, month=month, category="stock"
         )
 
     def get_bond_holdings(self, year="", season="", month=""):
+        """
+        持仓债券细节
+
+        :param year:
+        :param season:
+        :param month:
+        :return: pd.DataFrame
+        """
         return get_fund_holdings(
             self.code, year, season=season, month=month, category="bond"
         )
 
+    def get_portfolio_holdings(self, date=None):
+        """
+        持仓股债现金占比
+
+        :param date:
+        :return: Dict
+        """
+        if date is None:
+            date = dt.datetime.now().strftime("%Y-%m-%d")
+        import xalpha.universal as xu
+
+        df = xu.get_daily("pt-F" + self.code, end=date)
+        if df is not None:
+            d = dict(df.iloc[-1])
+            del d["assets"], d["date"]
+            return d
+        else:
+            logger.warning("no portfolio information before %s" % date)
+            return
+
+    def get_industry_holdings(self, year="", season="", month="", threhold=0.5):
+        """
+        持仓行业占比
+
+        :param year:
+        :param season:
+        :param month:
+        :param threhold: float, 持仓小于该百分数的个股行业不再统计，加快速度
+        :return:  Dict
+        """
+        # 注意该 API 未直接使用天天基金的行业数据，其数据行业划分比较奇怪，大量行业都划分进了笼统的制造业，
+        # 用于分析代表性不强，甚至没有消费，医药等行业划分方式
+
+        from xalpha.universal import ttjjcode, get_industry_fromxq
+
+        df = self.get_stock_holdings(year=year, season=season, month=month)
+        if df is None:
+            logger.warning(
+                "%s has no stock holdings in %s y %s s. (Possible reason: 链接基金，债券基金)"
+                % (self.code, year, season)
+            )
+            return
+        d = {}
+        for i, row in df.iterrows():
+            if row["ratio"] < threhold:
+                continue
+            code = ttjjcode(row["code"])
+            industry = get_industry_fromxq(code)["industryname"]
+            if not industry.strip():
+                logger.warning(
+                    "%s has no industry information, cannot be classfied" % code
+                )
+            else:
+                if industry not in d:
+                    d[industry] = 0
+                d[industry] += row["ratio"]
+        return d
+
+    def which_industry(self, threhold=1.0):
+        """
+        Experimental API
+        当单一行业占比较其他行业的 threhold 倍还多时，自动判定为对应的行业基金
+        注意这里的行业可能比较细分，导致持仓多个行业其实是同一大行业从而误判为宽基基金的可能
+
+        :param threhold: float
+        :return: str
+        """
+        d = self.get_industry_holdings()
+        l = sorted([(k, v) for k, v in d.items()], key=lambda s: -s[1])
+        s0 = l[0][1]
+        s1 = sum([l[i][1] for i in range(1, len(l))])
+        if s0 > threhold * s1:
+            return "行业基金： " + l[0][0]
+        else:
+            return "宽基基金"
+
 
 class indexinfo(basicinfo):
     """
