@@ -170,6 +170,22 @@ def get_historical_fromxq(code, count, type_="before", full=False):
     return df
 
 
+@lru_cache()
+def get_industry_fromxq(code):
+    """
+    part of symbols has empty industry information
+
+    :param code:
+    :return: dict
+    """
+    url = (
+        "https://xueqiu.com/stock/industry/stockList.json?code=%s&type=1&size=100"
+        % code
+    )
+    r = rget_json(url, cookies={"xq_a_token": get_token()})
+    return r
+
+
 def get_historical_fromcninvesting(curr_id, st_date, end_date, app=False):
     data = {
         "curr_id": curr_id,
@@ -1310,6 +1326,8 @@ def get_rt_from_sina(code):
     if (
         code.startswith("SH") or code.startswith("SZ") or code.startswith("HK")
     ) and code[2:].isdigit():
+        # TODO: 20200819: API seems changed a bit, index shift?
+        # or things may get zero when the market is closed?
         if code.startswith("HK"):
             d["current"] = float(l[9])  # 英文股票名称占位
             d["currency"] = "HKD"
@@ -1411,16 +1429,21 @@ def get_rt_from_ycharts(code):
     url = "https://ycharts.com/" + code
     r = rget(url)
     s = BeautifulSoup(r.text, "lxml")
-    qdiv = s.select("div[class=quoteData]")  # current
+    qdiv = s.select("div.index-rank.col-auto")  # current
     spans = [s for s in qdiv[0].contents if s != "\n" and s.contents]
     d = {}
     d["name"] = s.select("h1,h3[class=securityName]")[0].text.strip()
-    d["current"], d["percent"], d["currency"] = (
+    d["current"], d["percent"] = (
         _float(spans[0].string),  # current,
-        _float(spans[1].contents[-1].string[:-1]),  # percent
-        spans[-1].string,  # currency
+        _float(spans[1].contents[-2].string[1:-1]),  # percent
     )
-    d["time"] = s.select("span[class*=quoteDate]")[0].string
+    l = [
+        c.strip()
+        for c in s.select("span[class=index-info]")[0].string.split("\n")
+        if c.strip()
+    ]
+    d["time"] = l[1]
+    d["currency"] = l[0].split(" ")[0].strip()
     d["market"] = None
     return d
 
